@@ -63,6 +63,8 @@ class BuildComponent:
         
     def handleDependencyModule(self, dependency: Dependency):
         module: Module = self.findModule(self.config.projects, dependency.name)
+        if module.build == 'false':
+            return
         upload_version = module.upload_version
         if upload_version == '':
             # 没有指定module version时，先编译上传module，然后取module工程版本号
@@ -83,7 +85,7 @@ class BuildComponent:
 
     def getGradlePlaceHolderValue(self, module: Module, placeHolder):
         fileType = [".gradle", ".properties"]
-        lookup_str = '^\s*e?x?t?\.?' + placeHolder + '[\s]*[=][\s]*([1-9]+.*)'
+        lookup_str = '^\s*e?x?t?\.?' + placeHolder + '[\s]*[=][\s]*\'?([1-9]+.*)\'?$'
         return Replace.get_string(self.projectDir, fileType, lookup_str)
 
     def build(self, option): 
