@@ -16,8 +16,12 @@ if [[ "$TEST" = false ]]; then
 	else
 		echo "command $cmd excute........"
 		./gradlew $cmd --stacktrace --info
-
-		cp -rf ${projectDir}/app/build/outputs ${outputs}
-	    echo "fetch your apk in $outputs"
+        
+		if [ $? -ne 0 ]; then
+		    echo "gradlew run error."
+		else
+            cp -rf ${projectDir}/app/build/outputs ${outputs}
+			echo "fetch your apk in $outputs"
+		fi
 	fi
 fi
\ No newline at end of file
